@@ -31,11 +31,11 @@ def main():
     args = mainArgs()
 
     if args.version:
-        print(f"clime-productivity version {version()}")
+        print(f"clime-productivity-compute version {version()}")
         quit(0)
 
     df: DataFrame = pandas.read_json(args.input).T
-    calculateProductivity(df).to_json(args.output)
+    calculateProductivity(df).to_json(args.output, indent=4)
 
 
 if __name__ == "__main__":
